==> appmesh-1.93.0-sources.jar: software/amazon/awscdk/services/appmesh/ServiceDiscoveryConfig.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * (experimental) Properties for VirtualNode Service Discovery.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:47:05.093Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.ServiceDiscoveryConfig")
@software.amazon.jsii.Jsii.Proxy(ServiceDiscoveryConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ServiceDiscoveryConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Cloud Map based Service Discovery.
     * <p>
     * Default: - no Cloud Map based service discovery
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty getCloudmap() {
        return null;
    }

    /**
     * (experimental) DNS based Service Discovery.
     * <p>
     * Default: - no DNS based service discovery
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty getDns() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ServiceDiscoveryConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ServiceDiscoveryConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<ServiceDiscoveryConfig> {
        private software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty cloudmap;
        private software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty dns;

        /**
         * Sets the value of {@link ServiceDiscoveryConfig#getCloudmap}
         * @param cloudmap Cloud Map based Service Discovery.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cloudmap(software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty cloudmap) {
            this.cloudmap = cloudmap;
            return this;
        }

        /**
         * Sets the value of {@link ServiceDiscoveryConfig#getDns}
         * @param dns DNS based Service Discovery.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dns(software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty dns) {
            this.dns = dns;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ServiceDiscoveryConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public ServiceDiscoveryConfig build() {
            return new Jsii$Proxy(cloudmap, dns);
        }
    }

    /**
     * An implementation for {@link ServiceDiscoveryConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ServiceDiscoveryConfig {
        private final software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty cloudmap;
        private final software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty dns;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cloudmap = software.amazon.jsii.Kernel.get(this, "cloudmap", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty.class));
            this.dns = software.amazon.jsii.Kernel.get(this, "dns", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty cloudmap, final software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty dns) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cloudmap = cloudmap;
            this.dns = dns;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty getCloudmap() {
            return this.cloudmap;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty getDns() {
            return this.dns;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCloudmap() != null) {
                data.set("cloudmap", om.valueToTree(this.getCloudmap()));
            }
            if (this.getDns() != null) {
                data.set("dns", om.valueToTree(this.getDns()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.ServiceDiscoveryConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ServiceDiscoveryConfig.Jsii$Proxy that = (ServiceDiscoveryConfig.Jsii$Proxy) o;

            if (this.cloudmap != null ? !this.cloudmap.equals(that.cloudmap) : that.cloudmap != null) return false;
            return this.dns != null ? this.dns.equals(that.dns) : that.dns == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cloudmap != null ? this.cloudmap.hashCode() : 0;
            result = 31 * result + (this.dns != null ? this.dns.hashCode() : 0);
            return result;
        }
    }
}

==> appmesh-1.182.0-sources.jar: software/amazon/awscdk/services/appmesh/ServiceDiscoveryConfig.java <==
package software.amazon.awscdk.services.appmesh;

/**
 * Properties for VirtualNode Service Discovery.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.appmesh.*;
 * ServiceDiscoveryConfig serviceDiscoveryConfig = ServiceDiscoveryConfig.builder()
 *         .cloudmap(AwsCloudMapServiceDiscoveryProperty.builder()
 *                 .namespaceName("namespaceName")
 *                 .serviceName("serviceName")
 *                 // the properties below are optional
 *                 .attributes(List.of(AwsCloudMapInstanceAttributeProperty.builder()
 *                         .key("key")
 *                         .value("value")
 *                         .build()))
 *                 .ipPreference("ipPreference")
 *                 .build())
 *         .dns(DnsServiceDiscoveryProperty.builder()
 *                 .hostname("hostname")
 *                 // the properties below are optional
 *                 .ipPreference("ipPreference")
 *                 .responseType("responseType")
 *                 .build())
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:46.332Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.appmesh.$Module.class, fqn = "@aws-cdk/aws-appmesh.ServiceDiscoveryConfig")
@software.amazon.jsii.Jsii.Proxy(ServiceDiscoveryConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ServiceDiscoveryConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * Cloud Map based Service Discovery.
     * <p>
     * Default: - no Cloud Map based service discovery
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty getCloudmap() {
        return null;
    }

    /**
     * DNS based Service Discovery.
     * <p>
     * Default: - no DNS based service discovery
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty getDns() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ServiceDiscoveryConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ServiceDiscoveryConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ServiceDiscoveryConfig> {
        software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty cloudmap;
        software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty dns;

        /**
         * Sets the value of {@link ServiceDiscoveryConfig#getCloudmap}
         * @param cloudmap Cloud Map based Service Discovery.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cloudmap(software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty cloudmap) {
            this.cloudmap = cloudmap;
            return this;
        }

        /**
         * Sets the value of {@link ServiceDiscoveryConfig#getDns}
         * @param dns DNS based Service Discovery.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder dns(software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty dns) {
            this.dns = dns;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ServiceDiscoveryConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ServiceDiscoveryConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ServiceDiscoveryConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ServiceDiscoveryConfig {
        private final software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty cloudmap;
        private final software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty dns;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cloudmap = software.amazon.jsii.Kernel.get(this, "cloudmap", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty.class));
            this.dns = software.amazon.jsii.Kernel.get(this, "dns", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cloudmap = builder.cloudmap;
            this.dns = builder.dns;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.CfnVirtualNode.AwsCloudMapServiceDiscoveryProperty getCloudmap() {
            return this.cloudmap;
        }

        @Override
        public final software.amazon.awscdk.services.appmesh.CfnVirtualNode.DnsServiceDiscoveryProperty getDns() {
            return this.dns;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getCloudmap() != null) {
                data.set("cloudmap", om.valueToTree(this.getCloudmap()));
            }
            if (this.getDns() != null) {
                data.set("dns", om.valueToTree(this.getDns()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-appmesh.ServiceDiscoveryConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ServiceDiscoveryConfig.Jsii$Proxy that = (ServiceDiscoveryConfig.Jsii$Proxy) o;

            if (this.cloudmap != null ? !this.cloudmap.equals(that.cloudmap) : that.cloudmap != null) return false;
            return this.dns != null ? this.dns.equals(that.dns) : that.dns == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cloudmap != null ? this.cloudmap.hashCode() : 0;
            result = 31 * result + (this.dns != null ? this.dns.hashCode() : 0);
            return result;
        }
    }
}
